@@ -12,7 +12,7 @@ use ndarray::{s, Array2};
 
 use std::io;
 use std::fs;
-use std::path::{Path, PathBuf};
+use std::path::Path;
 use std::convert::TryFrom;
 use std::cmp::min;
 
@@ -102,19 +102,37 @@ impl EmbeddedImage {
 }
 
 impl ExternalImage {
-    /// Tries to embed the external images by loading it from the file `mapres/<image_name>`
-    pub fn embed(&self) -> Result<EmbeddedImage, ImageError> {
+    /// Tries to embed the external images by loading them from the file `<mapres_directory>/<image_name>`
+    pub fn embed<P: AsRef<Path>>(&self, mapres_directory: P) -> Result<EmbeddedImage, ImageError> {
         let mut file_name = self.name.clone();
         file_name.push_str(".png");
 
-        let mut path: PathBuf = "mapres".into();
-        path.push(file_name);
+        let path = mapres_directory.as_ref().join(&file_name);
 
         EmbeddedImage::from_file(path)
     }
 }
 
-// takes care of multiple physics layers of the same type
+impl TwMap {
+    /// Tries to embed the external images by loading them from the file `<mapres_directory>/<image_name>`
+    pub fn embed_images<P: AsRef<Path>>(&mut self, mapres_directory: P) -> Result<(), ImageError> {
+        let mut result = Ok(());
+        for image in &mut self.images {
+            if let Image::External(ex) = image {
+                match ex.embed(mapres_directory.as_ref()) {
+                    Ok(emb) => *image = Image::Embedded(emb),
+                    Err(err) => {
+                        if result.is_ok() {
+                            result = Err(err);
+                        }
+                    }
+                }
+            }
+        }
+        result
+    }
+}
+
 impl TwMap {
     /// Removes duplicate physics layers of each type.
     /// Note that every map must have at most 1 physics layer of each type to pass the checks.
